@@ -63,13 +63,12 @@ fix_columns <- function(data, events, start, end, groups, tooltips) {
   } else {
     data$tooltip <- ifelse(data$start == data$end,
       paste0("<b>", data$event, ": ", data$start, "</b>"),
-      paste0("<b>", data$event, ":</b> from <b>",
+      paste0("<b>", data$event, "</b><br>from <b>",
              data$start, "</b> to <b>", data$end, "</b>")
     )
   }
 
   # shorten long labels
-  data$labelPos <- "center" # TODO: apply AI here
   data$label <- ifelse(data$start == data$end,
     ifelse(nchar(data$event) > 10,
            paste0(substr(data$event, 1, 13), "..."),
@@ -77,5 +76,5 @@ fix_columns <- function(data, events, start, end, groups, tooltips) {
     data$event
   )
 
-  return(data[, c("event", "start", "end", "group", "tooltip", "labelPos", "label", "col", "fontcol")])
+  return(data[, c("event", "start", "end", "group", "tooltip", "label", "col", "fontcol")])
 }
