@@ -1,25 +1,54 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----eval=FALSE----------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
+#  timeline_data <- data.frame(event=c("Event 1", "Event 2"), start = c("2020-06-06", "2020-10-01"), end = c("2020-10-01", "2020-12-31"), group = "My Events")
+#  vistime(timeline_data)
+
+## ---- echo=FALSE, out.width = "100%"------------------------------------------
+knitr::include_graphics("../inst/img/basic_plotly.png")
+
+## ---- eval = FALSE------------------------------------------------------------
+#  timeline_data <- data.frame(event=c("Event 1", "Event 2"), start = c("2020-06-06", "2020-10-01"), end = c("2020-10-01", "2020-12-31"), group = "My Events")
+#  gg_vistime(timeline_data)
+
+## ---- echo=FALSE, out.width = "100%"------------------------------------------
+knitr::include_graphics("../inst/img/basic_ggplot.png")
+
+## ---- eval = FALSE------------------------------------------------------------
+#  timeline_data <- data.frame(event=c("Event 1", "Event 2"), start = c("2020-06-06", "2020-10-01"), end = c("2020-10-01", "2020-12-31"), group = "My Events")
+#  vistime_data(timeline_data)
+#  
+#  #>     event      start        end     group                                      tooltip      col subplot   y
+#  #> 1 Event 1 2020-06-06 2020-10-01 My Events  from <b>2020-06-06</b> to <b>2020-10-01</b>  #8DD3C7       1   1
+#  #> 2 Event 2 2020-10-01 2020-12-31 My Events  from <b>2020-10-01</b> to <b>2020-12-31</b>  #FFFFB3       1   1
+
+## ----eval=FALSE---------------------------------------------------------------
 #  install.packages("vistime")
 
-## ----eval = FALSE, echo = FALSE------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  if(!require("devtools")) install.packages("devtools")
 #  devtools::install_github("shosaco/vistime")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  library(vistime)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  vistime(data, start = "start", end = "end", groups = "group", events = "event", colors = "color",
 #                fontcolors = "fontcolor", tooltips = "tooltip", optimize_y = TRUE, linewidth = NULL,
 #                title = NULL, show_labels = TRUE, background_lines = 10)
+#  
+#  gg_vistime(data, start = "start", end = "end", groups = "group", events = "event", colors = "color",
+#             fontcolors = "fontcolor", optimize_y = TRUE, linewidth = NULL, title = NULL,
+#             show_labels = TRUE, background_lines = 10)
+#  
+#  vistime_data(data, start = "start", end = "end", groups = "group", events = "event", colors = "color",
+#               fontcolors = "fontcolor", tooltips = "tooltip", optimize_y = TRUE)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  pres <- data.frame(Position = rep(c("President", "Vice"), each = 3),
 #                     Name = c("Washington", rep(c("Adams", "Jefferson"), 2), "Burr"),
 #                     start = c("1789-03-29", "1797-02-03", "1801-02-03"),
@@ -29,10 +58,10 @@ knitr::opts_chunk$set(
 #  
 #  vistime(pres, events="Position", groups="Name", title="Presidents of the USA")
 
-## ---- echo=FALSE, out.width = "100%"-------------------------------------
+## ---- echo=FALSE, out.width = "100%"------------------------------------------
 knitr::include_graphics("../inst/img/ex2.png")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  data <- read.csv(text="event,group,start,end,color
 #                         Phase 1,Project,2016-12-22,2016-12-23,#c8e6c9
 #                         Phase 2,Project,2016-12-23,2016-12-29,#a5d6a7
@@ -43,7 +72,6 @@ knitr::include_graphics("../inst/img/ex2.png")
 #                         Room 335,Team 1,2017-01-05,2017-01-23,#9ECAE1
 #                         Group 1,Team 2,2016-12-22,2016-12-28,#E5F5E0
 #                         Group 2,Team 2,2016-12-28,2017-01-23,#C7E9C0
-#                         1-217.0,category 2,2016-12-27,2016-12-27,#90caf9
 #                         3-200,category 1,2016-12-25,2016-12-25,#1565c0
 #                         3-330,category 1,2016-12-25,2016-12-25,#1565c0
 #                         3-223,category 1,2016-12-28,2016-12-28,#1565c0
@@ -51,6 +79,7 @@ knitr::include_graphics("../inst/img/ex2.png")
 #                         3-226,category 1,2016-12-28,2016-12-28,#1565c0
 #                         3-226,category 1,2017-01-19,2017-01-19,#1565c0
 #                         3-330,category 1,2017-01-19,2017-01-19,#1565c0
+#                         1-217.0,category 2,2016-12-27,2016-12-27,#90caf9
 #                         4-399.7,moon rising,2017-01-13,2017-01-13,#f44336
 #                         8-831.0,sundowner drink,2017-01-17,2017-01-17,#8d6e63
 #                         9-984.1,birthday party,2016-12-22,2016-12-22,#90a4ae
@@ -61,14 +90,33 @@ knitr::include_graphics("../inst/img/ex2.png")
 #  
 #  vistime(data)
 
-## ----echo=FALSE, out.width = "100%"--------------------------------------
+## ----echo=FALSE, out.width = "100%"-------------------------------------------
 knitr::include_graphics("../inst/img/ex3.png")
 
-## ----eval=FALSE----------------------------------------------------------
-#  chart <- vistime(pres, events="Position")
-#  export(chart, file = "presidents.pdf")
+## ----eval=FALSE---------------------------------------------------------------
+#  data <- read.csv(text="event,start,end
+#                         Phase 1,2020-12-15,2020-12-24
+#                         Phase 2,2020-12-23,2020-12-29
+#                         Phase 3,2020-12-28,2021-01-06
+#                         Phase 4,2021-01-06,2021-02-02")
+#  
+#  vistime(data, optimize_y = TRUE)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----echo=FALSE, out.width = "100%"-------------------------------------------
+knitr::include_graphics("../inst/img/optimize_y_T.png")
+
+## ----eval=FALSE---------------------------------------------------------------
+#  vistime(data, optimize_y = FALSE)
+
+## ----echo=FALSE, out.width = "100%"-------------------------------------------
+knitr::include_graphics("../inst/img/optimize_y_F.png")
+
+## ----eval=FALSE---------------------------------------------------------------
+#  # webshot::install_phantomjs()
+#  chart <- vistime(pres, events="Position")
+#  plotly::export(chart, file = "presidents.pdf")
+
+## ----eval=FALSE---------------------------------------------------------------
 #  library(shiny)
 #  library(plotly)
 #  library(vistime)
@@ -89,7 +137,7 @@ knitr::include_graphics("../inst/img/ex3.png")
 #    }
 #  )
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  pres <- data.frame(Position = rep(c("President", "Vice"), each = 3),
 #                     Name = c("Washington", rep(c("Adams", "Jefferson"), 2), "Burr"),
 #                     start = c("1789-03-29", "1797-02-03", "1801-02-03"),
@@ -100,6 +148,7 @@ knitr::include_graphics("../inst/img/ex3.png")
 #  p <- vistime(pres, events="Position", groups="Name", title="Presidents of the USA")
 #  
 #  # step 1: transform into a list
+#  library(plotly)
 #  pp <- plotly_build(p)
 #  
 #  # step 2: change the font size
@@ -107,21 +156,17 @@ knitr::include_graphics("../inst/img/ex3.png")
 #  
 #  pp
 
-## ----echo=FALSE, out.width = "50%"---------------------------------------
+## ----echo=FALSE, out.width = "50%"--------------------------------------------
 knitr::include_graphics("../inst//img/ex2-tickfontsize.png")
 
-## ----eval=FALSE----------------------------------------------------------
-#  # loop through the yaxes and change the font size for each element:
-#  for(i in grep("yaxis*", names(pp$x$layout))){
-#       pp$x$layout[[i]]$tickfont <- list(size = 28)
-#  }
-#  
+## ----eval=FALSE---------------------------------------------------------------
+#  pp$x$layout[["yaxis"]]$tickfont <- list(size = 28)
 #  pp
 
-## ----echo=FALSE, out.width = "50%"---------------------------------------
+## ----echo=FALSE, out.width = "50%"--------------------------------------------
 knitr::include_graphics("../inst//img/ex2-yfontsize.png")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  pres <- data.frame(Position = rep(c("President", "Vice"), each = 3),
 #                      Name = c("Washington", rep(c("Adams", "Jefferson"), 2), "Burr"),
 #                      start = c("1789-03-29", "1797-02-03", "1801-02-03"),
@@ -132,10 +177,11 @@ knitr::include_graphics("../inst//img/ex2-yfontsize.png")
 #  p <- vistime(pres, events="Position", groups="Name", title="Presidents of the USA")
 #  
 #  # step 1: transform into a list
+#  library(plotly)
 #  pp <- plotly_build(p)
 #  
 #  # step 2: loop over pp$x$data, and change the font size of all text elements to 28
-#  for(i in 1:length(pp$x$data)){
+#  for(i in seq_along(pp$x$data)){
 #      if(pp$x$data[[i]]$mode == "text") pp$x$data[[i]]$textfont$size <- 28
 #  }
 #  
@@ -146,29 +192,30 @@ knitr::include_graphics("../inst//img/ex2-yfontsize.png")
 #  
 #  pp
 
-## ----echo=FALSE, out.width = "50%"---------------------------------------
+## ----echo=FALSE, out.width = "50%"--------------------------------------------
 knitr::include_graphics("../inst//img/ex2-eventfontsize.png")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  dat <- data.frame(event = 1:4, start = c("2019-01-01", "2019-01-10"))
 #  
 #  p <- vistime(dat)
 #  
 #  # step 1: transform into a list
+#  library(plotly)
 #  pp <- plotly_build(p)
 #  
 #  # step 2: loop over pp$x$data, and change the marker size of all text elements to 50px
-#  for(i in 1:length(pp$x$data)){
-#      if(pp$x$data[[i]]$mode == "markers") pp$x$data[[i]]$marker$size <- 10
+#  for(i in 1:seq_along(pp$x$data)){
+#      if(pp$x$data[[i]]$mode == "markers") pp$x$data[[i]]$marker$size <- 50
 #  }
 #  
 #  pp
 #  
 #  # or, using purrr:
 #  # marker_idx <- which(purrr::map_chr(pp$x$data, "mode") == "markers")
-#  # for(i in marker_idx) pp$x$data[[i]]$marker$size <- 10
+#  # for(i in marker_idx) pp$x$data[[i]]$marker$size <- 50
 #  # pp
 
-## ----echo=FALSE, out.width = "50%"---------------------------------------
+## ----echo=FALSE, out.width = "50%"--------------------------------------------
 knitr::include_graphics("../inst//img/ex3-markersize.png")
 
